<?php
/* $Id: serbian_latin-windows-1250.inc.php 10110 2007-03-15 21:11:38Z lem9 $ */

/**
 * Translated by:
 *     Mihailo Stefanovic <mikis@users.sourceforge.net>, Branislav Jovanovic <fangorn@eunet.yu>
 *     Igor Mladenovic <mligor@zimco.com>, David Trajkovic <tdavid@ptt.yu>
 */

$charset = 'windows-1250';
$text_dir = 'ltr'; // ('ltr' for left to right, 'rtl' for right to left)
$number_thousands_separator = ',';
$number_decimal_separator = '.';
// shortcuts for Byte, Kilo, Mega, Giga, Tera, Peta, Exa
$byteUnits = array('bajtova', 'KB', 'MB', 'GB', 'TB', 'PB', 'EB');

$day_of_week = array('Ned', 'Pon', 'Uto', 'Sre', 'et', 'Pet', 'Sub');
$month = array('jan', 'feb', 'mar', 'apr', 'maj', 'jun', 'jul', 'avg', 'sep', 'okt', 'nov', 'dec');
// See http://www.php.net/manual/en/function.strftime.php to define the
// variable below
$datefmt = '%d. %B %Y. u %H:%M';
$timespanfmt = '%s dana, %s sati, %s minuta i %s sekundi';

$strAbortedClients = 'Prekinuto';
$strAccessDeniedExplanation = 'phpMyAdmin je pokuao da se povee na MySQL server, ali je server odbio povezivanje. Proverite naziv domaina, korisniko ime i lozinku u config.inc.php i uverite se da odgovaraju podacima koje ste dobili od administratora MySQL servera.';
$strAccessDenied = 'Pristup odbijen';
$strAction = 'Akcija';
$strAddAutoIncrement = 'Dodaj AUTO_INCREMENT vrednost';
$strAddConstraints = 'Dodaj ogranienja';
$strAddDeleteColumn = 'Dodaj/obrii kolonu';
$strAddDeleteRow = 'Dodaj/obrii polje za kriterijum';
$strAddFields = 'Dodaj %s polja';
$strAddHeaderComment = 'Dodaj komentar u zaglavlje (\\n razdvaja linije)';
$strAddIntoComments = 'Dodaj u komentare';
$strAddNewField = 'Dodaj novo polje';
$strAddPrivilegesOnDb = 'Dodaj privilegije na sledeoj bazi';
$strAddPrivilegesOnTbl = 'Dodaj privilegije na sledeoj tabeli';
$strAddSearchConditions = 'Dodaj uslove pretraivanja (deo "WHERE" upita):';
$strAddToIndex = 'Dodaj u klju &nbsp;%s&nbsp;kolona(e)';
$strAddUser = 'Dodaj novog korisnika';
$strAddUserMessage = 'Dodali ste novog korisnika.';
$strAdministration = 'Administracija';
$strAffectedRows = 'Obuhvaeno redova:';
$strAfterInsertBack = 'Nazad na prethodnu stranu';
$strAfterInsertNewInsert = 'Dodaj jo jedan novi red';
$strAfterInsertNext = 'Uredi sledei red';
$strAfterInsertSame = 'Vrati se na ovu stranu';
$strAfter = 'Posle %s';
$strAll = 'Sve';
$strAllTableSameWidth = 'Prikaz svih tabela iste irine?';
$strAlterOrderBy = 'Promeni redosled u tabeli';
$strAnalyzeTable = 'Analiziraj tabelu';
$strAnd = 'i';
$strAndThen = 'i onda';
$strAnIndex = 'Klju je upravo dodat %s';
$strAny = 'Bilo koji';
$strAnyHost = 'Bilo koji domain';
$strAnyUser = 'Bilo koji korisnik';
$strApproximateCount = 'Moe biti priblino. Vidite FAQ 3.11';
$strAPrimaryKey = 'Primarni klju je upravo dodat %s';
$strArabic = 'Arapski';
$strArmenian = 'Jermenski';
$strAscending = 'Rastui';
$strAtBeginningOfTable = 'Na poetku tabele';
$strAtEndOfTable = 'Na kraju tabele';
$strAttr = 'Atributi';
$strAutodetect = 'automatski';
$strAutomaticLayout = 'Automatski raspored';

$strBack = 'Nazad';
$strBaltic = 'Baltiki';
$strBeginCut = 'POETAK REZ';
$strBeginRaw = 'POETAK SIROVO';
$strBinary = 'Binarni';
$strBinaryDoNotEdit = 'Binarni - ne menjaj';
$strBinaryLog = 'Binarni dnevnik';
$strBinLogEventType = 'Vrsta dogaaja';
$strBinLogInfo = 'Informacije';
$strBinLogName = 'Naziv dnevnika';
$strBinLogOriginalPosition = 'Originalna pozicija';
$strBinLogPosition = 'Pozicija';
$strBinLogServerId = 'ID servera';
$strBookmarkAllUsers = 'Dozvoli svakom korisniku da pristupa ovom zapamenom upitu';
$strBookmarkDeleted = 'Obeleiva je upravo obrisan.';
$strBookmarkLabel = 'Naziv';
$strBookmarkQuery = 'Zapamen SQL-upit';
$strBookmarkThis = 'Zapamti SQL-upit';
$strBookmarkView = 'Vidi samo';
$strBrowseForeignValues = 'Pregledaj strane vrednosti';
$strBrowse = 'Pregled';
$strBufferPoolActivity = 'Aktivnost skupa prihvatnika';
$strBufferPool = 'Skup prihvatnika';
$strBufferPoolUsage = 'Korienje skupa prihvatnika';
$strBufferReadMissesInPercent = 'Promaaji itanja u %';
$strBufferReadMisses = 'Promaaji pri itanju';
$strBufferWriteWaits = 'ekanja na upis';
$strBufferWriteWaitsInPercent = 'ekanja na upis u %';
$strBulgarian = 'Bugarski';
$strBusyPages = 'Zauzete strane';
$strBzError = 'phpMyAdmin nije mogao da kompresuje sadraj baze zbog neispravne BZ2 ekstenzije u ovoj verziji PHP-a. Preporuuje se da podesite <code>$cfg[\'BZipDump\']</code> direktivu u vaoj phpMyAdmin konfiguracionoj datoteci na <code>FALSE</code>. Ako elite da koristite mogunosti BZ2 kompresije, trebalo bi da preete na noviju verziju PHP-a. Vidite PHP izvetaj o grekama %s za detalje.';
$strBzip = '"bzip-ovano"';

$strCalendar = 'Kalendar';
$strCannotLogin = 'Ne mogu da se prijavim na MySQL server';
$strCantLoad = 'ne mogu da uitam ekstenziju %s,<br />molim proverite PHP konfiguraciju';
$strCantLoadRecodeIconv = 'Ne mogu da uitam iconv ili recode ekstenzije potrebne za konverziju skupova znakova, podesite PHP da dozvoli korienje ovih ekstenzija ili onemoguite konverziju skupova znakova u phpMyAdmin-u.';
$strCantRenameIdxToPrimary = 'Ne mogu da promenim klju u PRIMARY (primarni) !';
$strCantUseRecodeIconv = 'Ne mogu da koristim iconv ili libiconv ili recode_string funkcije iako ekstenzija prijavljuje da je uitana. Proverite vau PHP konfiguraciju.';
$strCardinality = 'Kardinalnost';
$strCaseInsensitive = 'Ne razlikuje mala i velika slova';
$strCaseSensitive = 'Razlikuje mala i velika slova';
$strCentralEuropean = 'Centralnoevropski';
$strChangeCopyModeCopy = '... sauvaj stare.';
$strChangeCopyModeDeleteAndReload = ' ... obrii starog iz tabele korisnika i zatim ponovo uitaj privilegije.';
$strChangeCopyModeJustDelete = ' ... obrii stare iz tabela korisnika.';
$strChangeCopyMode = 'Napravi novog korisnika sa istim privilegijama i ...';
$strChangeCopyModeRevoke = ' ... obustavi sve privilegije starog korisnika i zatim ga obrii.';
$strChangeCopyUser = 'Promeni informacije o prijavi / Kopiraj korisnika';
$strChangeDisplay = 'Izaberi polja za prikaz';
$strChangePassword = 'Promeni lozinku';
$strChange = 'Promeni';
$strCharset = 'Karakter set';
$strCharsetOfFile = 'Karakter set datoteke:';
$strCharsetsAndCollations = 'Karakter setovi i sortiranje';
$strCharsets = 'Kodne strane';
$strCheckAll = 'Oznai sve';
$strCheckOverhead = 'Proveri prekoraenja';
$strCheckPrivsLong = 'Proveri privilegije za bazu &quot;%s&quot;.';
$strCheckPrivs = 'Proveri privilegije';
$strCheckTable = 'Proveri tabelu';
$strChoosePage = 'Izaberite stranu koju menjate';
$strColComFeat = 'Prikazujem komentare kolone';
$strCollation = 'Sortiranje';
$strColumnNames = 'Imena kolona';
$strColumnPrivileges = 'Privilegije vezane za kolone';
$strCommand = 'Naredba';
$strCommentsForTable = 'KOMENTARI TABELE';
$strComments = 'Komentari';
$strCompatibleHashing = 'MySQL&nbsp;4.0 kompatibilno';
$strCompleteInserts = 'Kompletan INSERT (sa imenima polja)';
$strCompression = 'Kompresija';
$strConfigFileError = 'phpMyAdmin nije mogao da proita vau konfiguracionu datoteku!<br />Ovo se moe desiti ako PHP nae greku u procesiranju ili ne moe da pronae datoteku.<br />Pozovite konfiguracionu datoteku direktno koristei donji link i proitajte poruke o greci koje dobijate. U veini sluajeve negde nedostaje navodnik ili taka-zarez.<br />Ako dobijete praznu stranu, sve je u redu.';
$strConfigureTableCoord = 'Podesite koordinate za tabelu %s';
$strConnectionError = 'Ne mogu da se poveem: neispravna podeavanja.';
$strConnections = 'Konekcije';
$strConstraintsForDumped = 'Ogranienja za izvezene tabele';
$strConstraintsForTable = 'Ogranienja za tabele';
$strCookiesRequired = 'Kolaii (Cookies) moraju u ovom sluaju biti aktivni.';
$strCopyDatabaseOK = 'Baza %s je prekopirana u %s';
$strCopy = 'Kopiraj';
$strCopyTable = 'Kopiraj tabelu u (baza<b>.</b>tabela):';
$strCopyTableOK = 'Tabela %s je kopirana u %s.';
$strCopyTableSameNames = 'Ne mogu da kopiram tabelu u samu sebe!';
$strCouldNotKill = 'phpMyAdmin nije mogao da prekine proces %s. Verovatno je ve zatvoren.';
$strCreateDatabaseBeforeCopying = 'CREATE DATABASE pre kopiranja';
$strCreateIndex = 'Napravi klju na&nbsp;%s&nbsp;kolona';
$strCreateIndexTopic = 'Napravi novi klju';
$strCreate = 'Napravi';
$strCreateNewDatabase = 'Napravi novu bazu podataka';
$strCreateNewTable = 'Napravi novu tabelu u bazi %s';
$strCreatePage = 'Napravi novu stranu';
$strCreatePdfFeat = 'Pravljenje PDF-ova';
$strCreationDates = 'Datumi kreiranja/auriranja/provere';
$strCriteria = 'Kriterijum';
$strCroatian = 'Hrvatski';
$strCSVOptions = 'CSV opcije';
$strCyrillic = 'irilini';
$strCzech = 'eki';
$strCzechSlovak = 'eko-slovaki';

$strDanish = 'Danski';
$strDatabase = 'Baza podataka';
$strDatabaseEmpty = 'Ime baze nije zadato!';
$strDatabaseExportOptions = 'Opcije za izvoz baze';
$strDatabaseHasBeenDropped = 'Baza %s je odbaena.';
$strDatabaseNoTable = 'Baza ne sadri tabele!';
$strDatabases = 'Baze';
$strDatabasesDropped = '%s baza je uspeno odbaeno.';
$strDatabasesStatsDisable = 'Iskljui statistike';
$strDatabasesStatsEnable = 'Ukljui statistike';
$strDatabasesStatsHeavyTraffic = 'Napomena: ukljuivanje statistika moe prouzrokovati veliki saobraaj izmeu veb i MySQL servera.';
$strDatabasesStats = 'Statistika baze';
$strDataDict = 'Renik podataka';
$strDataOnly = 'Samo podaci';
$strDataPages = 'Strane sa podacima';
$strData = 'Podaci';
$strDBComment = 'Komentar baze:';
$strDBCopy = 'Kopiraj bazu u';
$strDbPrivileges = 'Privilegije vezane za bazu';
$strDBRename = 'Preimenuj bazu u';
$strDbSpecific = 'Specifino za bazu';
$strDefaultEngine = '%s je podrazumevani pogon skladitenja na ovom MySQL serveru.';
$strDefault = 'Podrazumevano';
$strDefaultValueHelp = 'Za podrazumevanu vrednost, unesite samo jednu vrednost, bez kosih crta ili navodnika u ovom obliku: a';
$strDefragment = 'Defragmentiraj tabelu';
$strDelayedInserts = 'Koristi odloena umetanja';
$strDeleteAndFlushDescr = 'Ovo je najistiji nain, ali ponovno uitavanje privilegina moe da potraje.';
$strDeleteAndFlush = 'Obrii korisnike i ponovo uitaj privilegije.';
$strDeleted = 'Red je obrisan';
$strDeletedRows = 'Obrisani redovi:';
$strDelete = 'Obrii';
$strDeleting = 'Briem %s';
$strDelOld = 'Trenutna strana ima reference na tabele koje vie ne postoje. elite li da obriete te reference?';
$strDescending = 'Opadajui';
$strDescription = 'Opis';
$strDictionary = 'renik';
$strDirtyPages = 'Prljave strane';
$strDisabled = 'Onemogueno';
$strDisableForeignChecks = 'Iskljui provere stranih kljueva';
$strDisplayFeat = 'Prikai osobine';
$strDisplayOrder = 'Redosled prikaza:';
$strDisplayPDF = 'Prikai PDF shemu';
$strDoAQuery = 'Napravi "upit po primeru" (doker: "%")';
$strDocu = 'Dokumentacija';
$strDoYouReally = 'Da li stvarno hoete da ';
$strDropDatabaseStrongWarning = 'Ovim ete UNITITI kompletnu bazu podataka!';
$strDrop = 'Odbaci';
$strDropUsersDb = 'Odbaci baze koje se zovu isto kao korisnici.';
$strDumpingData = 'Prikaz podataka tabele';
$strDumpSaved = 'Sadraj baze je sauvan u datoteku %s.';
$strDumpXRows = 'Prikai %s redova poevi od reda %s.';
$strDynamic = 'dinamiki';

$strEditPDFPages = 'Ureivanje PDF strana';
$strEditPrivileges = 'Promeni privilegije';
$strEdit = 'Promeni';
$strEffective = 'Efektivne';
$strEmpty = 'Isprazni';
$strEmptyResultSet = 'MySQL je vratio prazan rezultat (nula redova).';
$strEnabled = 'Omogueno';
$strEncloseInTransaction = 'Obavi izvoz u transakciji';
$strEndCut = 'KRAJ REZ';
$strEnd = 'Kraj';
$strEndRaw = 'KRAJ SIROVO';
$strEngineAvailable = '%s je dostupan na ovom MySQL serveru.';
$strEngineDisabled = '%s je onemoguen na ovom MySQL serveru.';
$strEngines = 'Skladitenja';
$strEngineUnsupported = 'Ovaj MySQL server ne podrava %s pogon skladitenja.';
$strEnglish = 'Engleski';
$strEnglishPrivileges = ' Napomena: MySQL imena privilegija moraju da budu na engleskom ';
$strError = 'Greka';
$strEscapeWildcards = 'Pre dokera _ i % treba staviti znak \ ako ih koristite samostalno';
$strEstonian = 'Estonski';
$strExcelEdition = 'Excel izdanje';
$strExcelOptions = 'Excel opcije';
$strExecuteBookmarked = 'Izvri upamen upit';
$strExplain = 'Objasni SQL';
$strExport = 'Izvoz';
$strExtendedInserts = 'Proireni INSERT';
$strExtra = 'Dodatno';

$strFailedAttempts = 'Neuspelih pokuaja';
$strFieldHasBeenDropped = 'Polje %s je obrisano';
$strField = 'Polje';
$strFieldsEmpty = ' Broj polja je nula! ';
$strFieldsEnclosedBy = 'Polja ograniena sa';
$strFieldsEscapedBy = 'Escape karakter &nbsp; &nbsp; &nbsp;';
$strFields = 'Polja';
$strFieldsTerminatedBy = 'Polja razdvojena sa';
$strFileAlreadyExists = 'Datoteka %s ve postoji na serveru, promenite ime datoteke ili ukljuite opciju prepisivanja.';
$strFileCouldNotBeRead = 'Datoteku nije mogue proitati';
$strFileNameTemplate = 'ablon imena datoteke';
$strFileNameTemplateRemember = 'zapamti ablon';
$strFixed = 'sreeno';
$strFlushPrivilegesNote = 'Napomena: phpMyAdmin uzima privilegije korisnika direktno iz MySQL tabela privilegija. Sadraj ove tabele moe se razlikovati od privilegija koje server koristi ako su vrene rune izmene. U tom sluaju %sponovo uitajte privilegije%s pre nego to nastavite.';
$strFlushTable = 'Osvei tabelu ("FLUSH")';
$strFormat = 'Format';
$strFormEmpty = 'Nedostaje vrednost u obrascu!';
$strFreePages = 'Slobodne strane';
$strFullText = 'Pun tekst';
$strFunction = 'Funkcija';

$strGenBy = 'Generisao';
$strGeneralRelationFeat = 'Opte osobine relacija';
$strGenerate = 'Napravi';
$strGeneratePassword = 'Napravi lozinku';
$strGenTime = 'Vreme kreiranja';
$strGeorgian = 'Gruzijski';
$strGerman = 'Nemaki';
$strGlobal = 'globalno';
$strGlobalPrivileges = 'Globalne privilegije';
$strGlobalValue = 'Globalna vrednost';
$strGo = 'Kreni';
$strGrantOption = 'Omogui';
$strGreek = 'Grki';
$strGzip = '"gzip-ovano"';

$strHasBeenAltered = 'je promenjen(a).';
$strHasBeenCreated = 'je kreiran(a).';
$strHaveToShow = 'Morate izabrati bar jednu kolonu za prikaz';
$strHebrew = 'Hebrejski';
$strHexForBinary = 'Koristi heksadecimalno za binarna polja';
$strHomepageOfficial = 'phpMyAdmin veb sajt';
$strHome = 'Poetna strana';
$strHost = 'Domain';
$strHostEmpty = 'Ime domaina je prazno!';
$strHTMLExcel = 'Microsoft Excel 2000';
$strHTMLExcelOptions = 'Opcije izvoza u Microsoft Excel 2000';
$strHTMLWord = 'Microsoft Word 2000';
$strHTMLWordOptions = 'Opcije izvoza u Microsoft Word 2000';
$strHungarian = 'Maarski';

$strIcelandic = 'Islandski';
$strId = 'ID';
$strIdxFulltext = 'Tekst klju';
$strIgnore = 'Ignorii';
$strIgnoreInserts = 'Ignorii duplikate pri umetanju';
$strImportFiles = 'Uvoz datoteka';
$strIndexes = 'Kljuevi';
$strIndexHasBeenDropped = 'Klju %s je obrisan';
$strIndex = 'Klju';
$strIndexName = 'Ime kljua :';
$strIndexType = 'Tip kljua :';
$strIndexWarningMultiple = 'Vie od jednog %s kljua je napravljeno za kolonu `%s`';
$strIndexWarningPrimary = 'PRIMARY i INDEX kljuevi ne bi trebali da budu istovremeno postavljeni za kolonu `%s`';
$strIndexWarningTable = 'Problem pri indeksiranju tabele `%s`';
$strIndexWarningUnique = 'UNIQUE i INDEX kljuevi ne bi trebali da budu istovremeno postavljeni za kolonu `%s`';
$strInnoDBAutoextendIncrementDesc = ' Veliina koraka proirenja veliine tabela koje se automatski proiruju kada se napune.';
$strInnoDBAutoextendIncrement = 'Korak automatskog proirenja';
$strInnoDBBufferPoolSizeDesc = 'Veliina memorijskog prihvatnika koje InnoDB koristi za keiranje podataka i indeksa svojih tabela.';
$strInnoDBBufferPoolSize = 'Veliina prihvatnika';
$strInnoDBDataFilePath = 'Datoteke sa podacima';
$strInnoDBDataHomeDirDesc = 'Zajedniki deo putanje direktorijuma za sve InnoDB datoteke sa podacima.';
$strInnoDBDataHomeDir = 'Osnovni direktorijum podataka';
$strInnoDBPages = 'strana';
$strInnodbStat = 'InnoDB status';
$strInsecureMySQL = 'Vaa konfiguraciona datoteka sadri podeavanja (root bez lozinke) koja odgovaraju standardnom MySQL privilegovanom nalogu. Va MySQL server radi sa ovim podeavanjima, otvoren je za upade, i zaista treba da ispravite ovaj sigurnosni rizik.';
$strInsertAsNewRow = 'Unesi kao novi red';
$strInsertedRowId = 'ID umetnutih redova:';
$strInsertedRows = 'Uneseno redova:';
$strInsert = 'Novi zapis';
$strInternalNotNecessary = '* Unutranja relacija nije neophodna kada postoji i u InnoDB.';
$strInternalRelations = 'Unutranje relacije';
$strInUse = 'se koristi';
$strInvalidColumnCount = 'Broj kolona mora biti vei od nule.';
$strInvalidFieldAddCount = 'Morate dodati barem jedno polje.';
$strInvalidFieldCount = 'Tabela mora imati barem jedno polje.';
$strInvalidRowNumber = '%d nije ispravan broj reda.';

$strJapanese = 'Japanski';
$strJumpToDB = 'Prei na bazu &quot;%s&quot;.';
$strJustDeleteDescr = '&quot;Obrisani&quot; korisnici e i dalje imati pristup serveru dok privilegije ne budu ponovo uitane.';
$strJustDelete = 'Samo obrii korisnike iz tabele privilegija.';

$strKeepPass = 'Nemoj da menja lozinku';
$strKeyname = 'Ime kljua';
$strKill = 'Obustavi';
$strKorean = 'Korejski';

$strLandscape = 'Poloeno';
$strLatchedPages = 'Zabravljene strane';
$strLatexCaption = 'Komentar tabele';
$strLatexContent = 'Sadraj tabele __TABLE__';
$strLatexContinuedCaption = 'Nastavljen komentar tabele';
$strLatexContinued = '(nastavljeno)';
$strLatexIncludeCaption = 'Ukljui komentar tabele';
$strLatexLabel = 'Oznaka kljua';
$strLaTeX = 'LaTeX';
$strLaTeXOptions = 'LaTeX opcije';
$strLatexStructure = 'Struktura tabele __TABLE__';
$strLatvian = 'Letonski';
$strLengthSet = 'Duina/Vrednost*';
$strLimitNumRows = 'Broj redova po strani';
$strLinesTerminatedBy = 'Linije se zavravaju sa';
$strLinkNotFound = 'Veza nije pronaena';
$strLinksTo = 'Veze ka';
$strLithuanian = 'Litvanski';
$strLocalhost = 'Lokalni';
$strLocationTextfile = 'Lokacija tekstualne datoteke';
$strLoginInformation = 'Podaci o prijavi';
$strLogin = 'Prijavljivanje';
$strLogout = 'Odjavljivanje';
$strLogPassword = 'Lozinka:';
$strLogServer = 'Server';
$strLogUsername = 'Korisniko ime:';
$strLongOperation = 'Ova operacija moe da potraje. Da li da nastavimo?';

$strMaximumSize = 'Maksimalna veliina: %s%s';
$strMbExtensionMissing = 'mbstring PHP ekstenzija nije pronaena, a ini se da vi koristite viebajtni skup znakova. Bez mbstring ekstenzije phpMyAdmin ne moe ispravno da razdvaja stringove i to moe dovesti do neoekivanih rezultata.';
$strMbOverloadWarning = 'Ukljuena vam je mbstring.func_overload opcija u PHP podeavanjima. Ova opcija je nekompatibilna sa phpMyAdmin i moe dovesti do greaka u nekim podacima!';
$strMIME_available_mime = 'Dostupni MIME-tipovi';
$strMIME_available_transform = 'Dostupne transformacije';
$strMIME_description = 'Opis';
$strMIME_MIMEtype = 'MIME-tipovi';
$strMIME_nodescription = 'Nema opisa za ovu transformaciju.<br />Molimo pitajte autora ta %s radi.';
$strMIME_transformation_note = 'Za listu dostupnih opcija transformacije i njihove transformacije MIME-tipova, kliknite na %sopise transformacija%s';
$strMIME_transformation_options_note = 'Molimo unesite vrednosti za opcije transformacije koristei ovaj oblik: \'a\', 100, b,\'c\'...<br />Ako treba da unesete obrnutu kosu crtu ("\\") ili apostrof ("\'") u te vrednosti, stavite obrnutu kosu crtu ispred njih (na primer \'\\\\xyz\' ili \'a\\\'b\').';
$strMIME_transformation_options = 'Opcije transformacije';
$strMIME_transformation = 'Tranformacije itaa';
$strMIMETypesForTable = 'MIME TIPOVI ZA TABELU';
$strMIME_without = 'MIME-tipovi prikazani u kurzivu nemaju odvojene funkcije transformacije.';
$strModifications = 'Izmene su sauvane';
$strModifyIndexTopic = 'Izmeni klju';
$strModify = 'Promeni';
$strMoveTableOK = 'Tabela %s je pomerena u %s.';
$strMoveTable = 'Pomeri tabelu u (baza<b>.</b>tabela):';
$strMoveTableSameNames = 'Ne mogu da premestim tabelu u samu sebe!';
$strMultilingual = 'viejeziki';
$strMyISAMDataPointerSizeDesc = 'Podrazumevana veliina pokazivaa u bajtovima, koristi se pri CREATE TABLE za MyISAM tabele kada nije zadata opcija MAX_ROWS';
$strMyISAMDataPointerSize = 'Veliina pokazivaa podataka';
$strMyISAMMaxExtraSortFileSizeDesc = 'Ako bi privremena datoteka koja se koristi za brzo kreiranje MyISAM indeksa bila vea nego pri korienju kea kljueva za ovde zadatu vrednost, koristi metod keiranja kljueva';
$strMyISAMMaxExtraSortFileSize = 'Maksimalna veliina privremenih datoteka pri kreiranju indeksa';
$strMyISAMMaxSortFileSizeDesc = 'Maksimalna veliina privremenih datoteka koje MySQL sme da koristi pri re-kreiranju MyISAM indeksa (u toku REPAIR TABLE, ALTER TABLE, ili LOAD DATA INFILE operacija).';
$strMyISAMMaxSortFileSize = 'Maksimalna veliina privremenih datoteka za sortiranje';
$strMyISAMRecoverOptionsDesc = 'Reim automatskog oporavka puknutih MyISAM tabela, podeen pri startovanju servera opcijom --myisam-recover.';
$strMyISAMRecoverOptions = 'Reim automatskog oporavka';
$strMyISAMRepairThreadsDesc = 'Ako je vrednost vea od 1, indeksi MyISAM tabela se paralelno kreiraju (svaki indeks u sopstvenoj niti) za vreme procesa popravke sortiranjem.';
$strMyISAMRepairThreads = 'Niti popravke';
$strMyISAMSortBufferSizeDesc = 'Prihvatnik koji se alocira pri sortiranju MyISAM indeksa za vreme operacije REPAIR TABLE ili pri kreiranju indeksa sa CREATE INDEX ili ALTER TABLE.';
$strMyISAMSortBufferSize = 'Veliina prihvatnika za sortiranje';
$strMySQLCharset = 'MySQL set karaktera';
$strMySQLConnectionCollation = 'Sortiranje za MySQL vezu';
$strMySQLSaid = 'MySQL ree: ';
$strMySQLShowProcess = 'Prikai listu procesa';
$strMySQLShowStatus = 'Prikai MySQL informacije o toku rada';
$strMySQLShowVars = 'Prikai MySQL sistemske promenljive';

$strName = 'Ime';
$strNext = 'Sledei';
$strNoActivity = 'Nije bilo aktivnosti %s ili vie sekundi, molimo prijavite se ponovo';
$strNoDatabases = 'Baza ne postoji';
$strNoDatabasesSelected = 'Nije izabrana ni jedna baza.';
$strNoDescription = 'nema opisa';
$strNoDetailsForEngine = 'Nema detaljnijih informacija o statusu za ovaj pogon skladitenja.';
$strNoDropDatabases = '"DROP DATABASE" komanda je onemoguena.';
$strNoExplain = 'Preskoi objanjavanje SQL-a';
$strNoFrames = 'phpMyAdmin preferira itae koji podravaju okvire.';
$strNoIndex = 'Klju nije definisan!';
$strNoIndexPartsDefined = 'Delovi kljua nisu definisani!';
$strNoModification = 'Nema izmena';
$strNo = 'Ne';
$strNone = 'nema';
$strNoOptions = 'Ne postoje opcije za ovaj format';
$strNoPassword = 'Nema lozinke';
$strNoPermission = 'Veb serveru nije dozvoljeno da sauva datoteku %s.';
$strNoPhp = 'bez PHP koda';
$strNoPrivileges = 'Nema privilegija';
$strNoRights = 'Nije Vam dozvoljeno da budete ovde!';
$strNoRowsSelected = 'Nema odabranih redova';
$strNoSpace = 'Nedovoljno prostora za snimanje datoteke %s.';
$strNoTablesFound = 'Tabele nisu pronaene u bazi.';
$strNoThemeSupport = 'Nema podrke za teme, molimo proverite konfiguraciju i/ili teme u direktorijumu %s.';
$strNotNumber = 'Ovo nije broj!';
$strNotOK = 'nije u redu';
$strNotSet = '<b>%s</b> tabela nije pronaena ili nije postavljena u %s';
$strNoUsersFound = 'Korisnik nije naen.';
$strNoValidateSQL = 'Preskoi proveru SQL-a';
$strNull = 'Null';
$strNumSearchResultsInTable = '%s pogodaka unutar tabele <i>%s</i>';
$strNumSearchResultsTotal = '<b>Ukupno:</b> <i>%s</i> pogodaka';
$strNumTables = 'Tabele';

$strOK = 'U redu';
$strOperations = 'Operacije';
$strOperator = 'Operator';
$strOptimizeTable = 'Optimizuj tabelu';
$strOr = 'ili';
$strOverhead = 'Prekoraenje';
$strOverwriteExisting = 'Prepii postojee datoteke';

$strPageNumber = 'Broj strane:';
$strPagesToBeFlushed = 'Strane koje treba da budu usklaene';
$strPaperSize = 'Dimenzije papira';
$strPartialText = 'Deo teksta';
$strPasswordChanged = 'Lozinka za %s je uspeno promenjena.';
$strPasswordEmpty = 'Lozinka je prazna!';
$strPasswordHashing = 'Heiranje lozinke';
$strPassword = 'Lozinka';
$strPasswordNotSame = 'Lozinke nisu identine!';
$strPdfDbSchema = 'Shema baze "%s" - Strana %s';
$strPdfInvalidTblName = 'Tabela "%s" ne postoji!';
$strPdfNoTables = 'Nema tabela';
$strPerHour = 'na sat';
$strPerMinute = 'u minutu';
$strPerSecond = 'u sekundi';
$strPersian = 'Persijski';
$strPhoneBook = 'telefonski imenik';
$strPHP40203 = 'Koristite PHP 4.2.3, koji ima ozbiljan bag sa viebajtnim stringovima (mbstring). Pogledajte izvetaj o greci br. 19404. Ova verzija PHP-a se ne preporuuje za korienje sa phpMyAdmin.';
$strPhp = 'Napravi PHP kod';
$strPHPVersion = 'verzija PHP-a';
$strPmaDocumentation = 'phpMyAdmin dokumentacija';
$strPmaUriError = '<tt>$cfg[\'PmaAbsoluteUri\']</tt> direktiva MORA biti podeena u konfiguracionoj datoteci!';
$strPolish = 'Poljski';
$strPortrait = 'Uspravno';
$strPos1 = 'Poetak';
$strPrevious = 'Prethodna';
$strPrimaryKeyHasBeenDropped = 'Primarni klju je obrisan';
$strPrimaryKeyName = 'Ime primarnog kljua mora da bude... PRIMARY!';
$strPrimaryKeyWarning = '("PRIMARY" <b>mora</b> biti ime <b>samo</b> primarnog kljua!)';
$strPrimary = 'Primarni';
$strPrint = 'tampaj';
$strPrintViewFull = 'Pogled za tampu (sa punim tekstom)';
$strPrintView = 'Za tampu';
$strPrivDescAllPrivileges = 'Ukljuuje sve privilegije osim GRANT.';
$strPrivDescAlter = 'Dozvoljava izmenu struktura postojeih tabela.';
$strPrivDescAlterRoutine = 'Dozvoljava izmenu i odbacivanje sauvanih rutina.';
$strPrivDescCreateDb = 'Dozvoljava kreiranje novih baza i tabela.';
$strPrivDescCreateRoutine = 'Dozvoljava pravljenje sauvanih rutina.';
$strPrivDescCreateTbl = 'Dozvoljava kreiranje novih tabela.';
$strPrivDescCreateTmpTable = 'Dozvoljava kreiranje privremenih tabela..';
$strPrivDescCreateUser = 'Dozvoljava pravljenje, odbacivanje i preimenovanje korisnikih naloga.';
$strPrivDescCreateView = 'Dozvoli kreiranje novih pogleda.';
$strPrivDescDelete = 'Dozvoljava brisanje podataka.';
$strPrivDescDropDb = 'Dozvoljava odbacivanje baza i tabela.';
$strPrivDescDropTbl = 'Dozvoljava odbacivanje tabela.';
$strPrivDescExecute5 = 'Dozvoljava izvravanje sauvanih rutina.';
$strPrivDescExecute = 'Dozvoljava pokretanje sauvanih procedura. Nema efekta u ovoj verziji MySQL-a.';
$strPrivDescFile = 'Dozvoljava uvoz podataka i njihov izvoz u datoteke.';
$strPrivDescGrant = 'Dozvoljava dodavanje korisnika i privilegija bez ponovnog uitavanja tabela privilegija.';
$strPrivDescIndex = 'Dozvoljava kreiranje i brisanje kljueva.';
$strPrivDescInsert = 'Dozvoljava umetanje i zamenu podataka.';
$strPrivDescLockTables = 'Dozvoljava zakljuavanje tabela tekuim procesima.';
$strPrivDescMaxConnections = 'Ograniava broj novih konekcija koje korisnik moe ta otvori na sat.';
$strPrivDescMaxQuestions = 'Ograniava broj upita koje korisnik moe da uputi serveru za sat.';
$strPrivDescMaxUpdates = 'Ograniava broj komandi koje menjaju tabele ili baze koje korisnik moe da izvri na sat.';
$strPrivDescProcess3 = 'Dozvoljava prekidanje procesa drugih korisnika.';
$strPrivDescProcess4 = 'Dozvoljava pregled kompletnih upita u listi procesa.';
$strPrivDescReferences = 'Nema efekta u ovoj verziji MySQL-a.';
$strPrivDescReload = 'Dozvoljava ponovno uitavanje podeavanja servera i pranjenje kea servera.';
$strPrivDescReplClient = 'Daje pravo korisniku da pita gde su glavni/pomoni serveri.';
$strPrivDescReplSlave = 'Potrebno zbog pomonih servera za replikaciju.';
$strPrivDescSelect = 'Dozvoljava itanje podataka.';
$strPrivDescShowDb = 'Daje pristup kompletnoj listi baza.';
$strPrivDescShowView = 'Dozvoljava izvravanje SHOW CREATE VIEW upita.';
$strPrivDescShutdown = 'Dozvoljava gaenje servera.';
$strPrivDescSuper = ' Dozvoljava povezivanje iako je dostignut maksimalan broj dozvoljenih veza; Neophodno za veinu administrativnih opcija kao to su podeavanje globalnih promenljivih ili prekidanje procesa ostalih korisnika.';
$strPrivDescUpdate = 'Dozvoljava izmenu podataka.';
$strPrivDescUsage = 'Nema privilegija.';
$strPrivileges = 'Privilegije';
$strPrivilegesReloaded = 'Privilegije su uspeno ponovo uitane.';
$strProcesses = 'Procesi';
$strProcesslist = 'Lista procesa';
$strPutColNames = 'Stavi imena polja u prvi red';

$strQBEDel = 'Del';
$strQBEIns = 'Ins';
$strQBE = 'Upit po primeru';
$strQueryFrame = 'Prozor za upite';
$strQueryOnDb = 'SQL upit na bazi <b>%s</b>:';
$strQuerySQLHistory = 'SQL istorijat';
$strQueryStatistics = '<b>Statistike upita</b>: %s upita je postavljeno serveru od njegovog pokretanja.';
$strQueryTime = 'Upit je trajao %01.4f sekundi';
$strQueryType = 'Vrsta upita';
$strQueryWindowLock = 'Ne prepisuj ovaj upit izvan prozora';

$strReadRequests = 'Zahtevi za itanje';
$strReceived = 'Primljeno';
$strRecords = 'Zapisi';
$strReferentialIntegrity = 'Proveri referencijalni integritet:';
$strRefresh = 'Osvei';
$strRelationalSchema = 'Relaciona shema';
$strRelationNotWorking = 'Dodatne mogunosti za rad sa povezanim tabelama su iskljuene. Da biste saznali zato, kliknite %sovde%s.';
$strRelationsForTable = 'RELACIJE TABELE';
$strRelations = 'Relacije';
$strRelationView = 'Relacioni pogled';
$strReloadingThePrivileges = 'Ponovo uitavam privilegije';
$strRemoveSelectedUsers = 'Ukloni izabrane korisnike';
$strRenameDatabaseOK = 'Baza %s je preimenovana u %s';
$strRenameTableOK = 'Tabeli %s promenjeno ime u %s';
$strRenameTable = 'Promeni ime tabele u ';
$strRepairTable = 'Popravi tabelu';
$strReplaceNULLBy = 'Zameni NULL sa';
$strReplaceTable = 'Zameni podatke u tabeli sa podacima iz datoteke';
$strReset = 'Poniti';
$strResourceLimits = 'Ogranienja resursa';
$strReType = 'Ponovite unos';
$strRevokeAndDeleteDescr = 'Korisnici e i dalje imati USAGE privilegije dok se privilegije ponovo ne uitaju.';
$strRevokeAndDelete = 'Obustavi sve aktivne privilegije korisnika i zatim ih obrii.';
$strRevokeMessage = 'Zabranili ste privilegije za %s';
$strRevoke = 'Zabrani';
$strRomanian = 'Rumunski';
$strRowLength = 'Duina reda';
$strRowsFrom = ' redova poev od reda';
$strRowSize = 'Veliina reda';
$strRowsModeFlippedHorizontal = 'horizontalnom (rotirana zaglavlja)';
$strRowsModeHorizontal = 'horizontalnom';
$strRowsModeOptions = 'u %s modu i ponovi zaglavlje posle svakog %s reda';
$strRowsModeVertical = 'vertikalnom';
$strRows = 'Redova';
$strRowsStatistic = 'Statistike reda';
$strRunning = 'na serveru %s';
$strRunQuery = 'Izvri SQL upit';
$strRunSQLQuery = 'Izvri SQL upit(e) na bazi %s';
$strRussian = 'Ruski';

$strSaveOnServer = 'Sauvaj na server u direktorijum %s';
$strSave = 'Sauvaj';
$strScaleFactorSmall = 'Faktor umanjenja je premali da bi shema stala na jednu stranu';
$strSearchFormTitle = 'Pretraivanje baze';
$strSearchInTables = 'Unutar tabela:';
$strSearchNeedle = 'Rei ili vrednosti koje se trae (doker: "%"):';
$strSearchOption1 = 'bar jednu od rei';
$strSearchOption2 = 'sve rei';
$strSearchOption3 = 'taan izraz';
$strSearchOption4 = 'kao regularni izraz';
$strSearch = 'Pretraivanje';
$strSearchResultsFor = 'Rezultati pretrage za "<i>%s</i>" %s:';
$strSearchType = 'Trai:';
$strSecretRequired = 'Konfiguraciona datoteka zahteva tajnu lozinku (blowfish_secret).';
$strSelectADb = 'Izaberite bazu';
$strSelectAll = 'Izaberi sve';
$strSelectBinaryLog = 'Izaberite binarni dnevnik za pregled';
$strSelectFields = 'Izaberi polja (najmanje jedno)';
$strSelectNumRows = 'u upitu';
$strSelectTables = 'Izaberi tabele';
$strSend = 'Sauvaj kao datoteku';
$strSent = 'Poslato';
$strServerChoice = 'Izbor servera';
$strServerNotResponding = 'Server ne odgovara';
$strServer = 'Server';
$strServerStatus = 'Informacije o toku rada';
$strServerStatusUptime = 'Ovaj MySQL server radi ve %s. Pokrenut je %s.';
$strServerTabVariables = 'Promenljive';
$strServerTrafficNotes = '<b>Saobraaj servera</b>: Tabele pokazuju statistike mrenog saobraaja na ovom MySQL serveru od njegovog pokretanja.';
$strServerVars = 'Serverske promenljive i podeavanja';
$strServerVersion = 'Verzija servera';
$strSessionValue = 'Vrednost sesije';
$strSetEnumVal = 'Ako je polje "enum" ili "set", unesite vrednosti u formatu: \'a\',\'b\',\'c\'...<br />Ako vam treba obrnuta kosa crta ("\\") ili apostrof ("\'") koristite ih u "izbegnutom" (escaped) obliku (na primer \'\\\\xyz\' ili \'a\\\'b\').';
$strShowAll = 'Prikai sve';
$strShowColor = 'Prikai boju';
$strShowDatadictAs = 'Format renika podataka';
$strShowFullQueries = 'Prikai kompletne upite';
$strShowGrid = 'Prikai mreu';
$strShowingRecords = 'Prikaz zapisa';
$strShowPHPInfo = 'Prikai informacije o PHP-u';
$strShow = 'Prikai';
$strShowTableDimension = 'Prikai dimenzije tabele';
$strShowTables = 'Prikai tabele';
$strShowThisQuery = 'Prikai ponovo ovaj upit';
$strSimplifiedChinese = 'Pojednostavljeni kineski';
$strSingly = '(po jednom polju)';
$strSize = 'Veliina';
$strSlovak = 'Slovaki';
$strSlovenian = 'Slovenaki';
$strSocketProblem = '(ili prikljuak lokalnog MySQL servera nije ispravno podeen)';
$strSortByKey = 'Sortiraj po kljuu';
$strSort = 'Sortiranje';
$strSpaceUsage = 'Zauzee';
$strSpanish = 'panski';
$strSplitWordsWithSpace = 'Rei se odvajaju razmakom (" ").';
$strSQLExportType = 'Tip izvoza';
$strSQLOptions = 'SQL opcije';
$strSQLParserBugMessage = 'Postoji mogunost da ste pronali bag u SQL parseru. Molimo ispitajte svoj upit paljivo, i proverite da su navodnici ispravni i da ne nedostaju. Ostali mogui razlozi greke mogu biti da ste poslali binarnu datoteku van oblasti za obian tekst. Moete probati svoj upit u MySQL suelju komandne linije. Donja poruka o greci MySQL servera, ako je ima, moe vam pomoi u otkrivanju problema. Ako i dalje imate probleme ili ako parser ne uspeva tamo gde uspeva suelje komandne linije, svedite svoj SQL upit na jedan jedini upit koji stvara probleme i poaljite nam izvetaj o greci sa delom koda u donjoj REZ sekciji:';
$strSQLParserUserError = 'Izgleda da postoji greka u vaem SQL upitu. Ovde je poruka o greki MySQL servera, koja vam moe pomoi u otkrivanju problema';
$strSQLQuery = 'SQL upit';
$strSQLResult = 'SQL rezultat';
$strSQL = 'SQL';
$strSQPBugInvalidIdentifer = 'Neispravan identifikator';
$strSQPBugUnclosedQuote = 'Navodnik nije zatvoren';
$strSQPBugUnknownPunctuation = 'Nepoznat string interpunkcije';
$strStatCheckTime = 'Poslednja provera';
$strStatCreateTime = 'Napravljeno';
$strStatement = 'Ime';
$strStatUpdateTime = 'Poslednja izmena';
$strStatus = 'Status';
$strStorageEngine = 'Pogon skladitenja';
$strStorageEngines = 'Pogoni skladitenja';
$strStrucCSV = 'CSV format';
$strStrucData = 'Struktura i podaci';
$strStrucExcelCSV = 'CSV za MS Excel';
$strStrucNativeExcel = 'Izvorni MS Excel podaci';
$strStrucOnly = 'Samo struktura';
$strStructPropose = 'Predloi strukturu tabele';
$strStructure = 'Struktura';
$strSubmit = 'Poalji';
$strSuccess = 'Va SQL upit je uspeno izvren';
$strSum = 'Ukupno';
$strSwedish = 'vedski';
$strSwitchToDatabase = 'Prebaci se na kopiranu bazu';
$strSwitchToTable = 'Prei na kopiranu tabelu';

$strTableComments = 'Komentari tabele';
$strTableEmpty = 'Ima tabele je prazno!';
$strTableHasBeenDropped = 'Tabela %s je odbaena';
$strTableHasBeenEmptied = 'Tabela %s je ispranjena';
$strTableHasBeenFlushed = 'Tabela %s je osveena';
$strTableMaintenance = 'Radnje na tabeli';
$strTableOfContents = 'Sadraj';
$strTableOptions = 'Opcije tabele';
$strTables = '%s tabela';
$strTableStructure = 'Struktura tabele';
$strTable = 'Tabela';
$strTakeIt = 'preuzmi';
$strTblPrivileges = 'Privilegije vezane za tabele';
$strTextAreaLength = 'Zbog njehove veliine, polje<br />moda neete moi da izmenite';
$strThai = 'Tajski';
$strTheme = 'Tema / stil';
$strThisHost = 'Ovaj server';
$strThreadSuccessfullyKilled = 'Proces %s je uspeno prekinut.';
$strTime = 'Vreme';
$strToggleScratchboard = 'Ukljui/iskljui radnu tablu';
$strTotalUC = 'Ukupno';
$strTotal = 'ukupno';
$strTraditionalChinese = 'Tradicionalni kineski';
$strTraditionalSpanish = 'Tradicionalni panski';
$strTraffic = 'Saobraaj';
$strTransformation_application_octetstream__download = 'Prikazuje vezu za preuzimanje binarnih podataka za polje. Prva opcija je ime binarne datoteke. Druga opcija je mogue ime polja reda tabele koji sadri ime datoteke. Ako date drugu opciju, prva mora biti postavljena na prazan string';
$strTransformation_application_octetstream__hex = 'Prikazuje heksadecimalni prikaz podataka. Optional first parameter specifies how often space will be added (defaults to 2 nibbles).';  //to translate
$strTransformation_image_jpeg__inline = 'Prikazuje umanjenu sliku na koju je mogue kliknuti; opcije: irina, visina u pikselima (uva originalni odnos)';
$strTransformation_image_jpeg__link = 'Prikazuje link ka ovoj slici (npr. direktno preuzimanje iz BLOB-a).';
$strTransformation_image_png__inline = 'Prikai JPEG slike na strani';
$strTransformation_text_plain__external = 'SAMO LINUX: Pokree eksternu aplikaciju i popunjava podatke u poljima preko standardnog ulaza. Vraa standardni izlaz aplikacije. Podrazumevano je Tidy, za lepi prikaz HTML koda. Zbog sigurnosnih razloga, morate runo izmeniti datoteku libraries/transformations/text_plain__external.inc.php i dodati alate koje elite da koristite. Prva opcija je broj programa koje elite da koristite, a druga su parametri programa. Ako se trei parametar postavi na 1 izlaz e biti konvertovan koristei htmlspecialchars() (podrazumevano je 1). Ako je etvrti parametar postavljen na 1, NOWRAP e biti dodato eliji sa sadrajem tako da e izlaz biti prikazan bez izmena. (podrazumevano 1)';
$strTransformation_text_plain__formatted = 'uva originalno formatiranje polja. Escaping se ne vri.';
$strTransformation_text_plain__imagelink = 'Prikazuje sliku i link, polje sadri naziv datoteke; prva opcija je prefiks kao "http://domain.com/", druga opcija je irina u pikselima, trea je visina.';
$strTransformation_text_plain__link = 'Prikazuje link, polje sadri naziv datoteke; prva opcija je prefiks kao "http://domain.com/", druga opcija je naslov za link.';
$strTransformation_text_plain__substr = 'Pokazuje deo stringa. Prva opcija je broj znakova koje treba preskoiti od poetka stringa (podrazumevano 0). Druga opcija je broj vraenih znakova (podrazumevano: do kraja stringa). Trea opcija je string koji se dodaje kada doe do odsecanja (podrazumevano: ...) .';
$strTruncateQueries = 'Prikai skraene upite';
$strTurkish = 'Turski';
$strType = 'Tip';

$strUkrainian = 'Ukrajinski';
$strUncheckAll = 'nijedno';
$strUnicode = 'Unikod';
$strUnique = 'Jedinstveni';
$strUnknown = 'nepoznat';
$strUnselectAll = 'nita';
$strUpdatePrivMessage = 'Aurirali ste privilegije za %s.';
$strUpdateProfileMessage = 'Profil je promenjen.';
$strUpdateQuery = 'Auriraj upit';
$strUpdComTab = 'Molimo pogledajte u dokumentaciji kako se aurira tabela Column_comments';
$strUpgrade = 'Trebalo bi da unapredite va %s server na verziju %s ili noviju.';
$strUsage = 'Zauzee';
$strUseBackquotes = 'Koristi \' za ograniavanje imena polja';
$strUseHostTable = 'Koristi tabelu domaina';
$strUserAlreadyExists = 'Korisnik %s ve postoji!';
$strUserEmpty = 'Ime korisnika nije uneto!';
$strUser = 'Korisnik';
$strUserName = 'Ime korisnika';
$strUserNotFound = 'Izabrani korisnik nije pronaen u tabeli privilegija.';
$strUserOverview = 'Pregled korisnika';
$strUsersDeleted = 'Izabrani korisnici su uspeno obrisani.';
$strUsersHavingAccessToDb = 'Korisnici koji imaju pristup &quot;%s&quot;';
$strUseTabKey = 'Koristite TAB taster za pomeranje od polja do polja, ili CTRL+strelice za slobodno pomeranje';
$strUseTables = 'Koristi tabele';
$strUseTextField = 'Koristi tekst polje';
$strUseThisValue = 'Koristi ovu vrednost';

$strValidateSQL = 'Proveri SQL';
$strValidatorError = 'SQL validator nije mogao da bude pokrenut. Proverite da li su instalirane neophodne PHP ekstenzije opisane u  %sdokumentaciji%s.';
$strValue = 'Vrednost';
$strVar = 'Promenljiva';
$strVersionInformation = 'Informacije o verziji';
$strViewDumpDatabases = 'Prikai sadraj (shemu) baze';
$strViewDumpDB = 'Prikai sadraj (shemu) baze';
$strViewDump = 'Prikai sadraj (shemu) tabele';
$strViewHasBeenDropped = 'Pogled %s je odbaen';
$strView = 'Pogled';

$strWebServerUploadDirectory = 'direktorijum za slanje veb servera ';
$strWebServerUploadDirectoryError = 'Direktorijum koji ste izabrali za slanje nije dostupan';
$strWelcome = 'Dobrodoli na %s';
$strWestEuropean = 'Zapadnoevropski';
$strWildcard = 'doker';
$strWindowNotFound = 'Odredini prozor pretraivaa nije mogao da bude auriran. Moda ste zatvorili matini prozor, ili va pretraiva onemoguava auriranje meu prozorima zbog sigurnosnih podeavanja';
$strWithChecked = 'Oznaeno:';
$strWriteRequests = 'Zahtevi za upis';
$strWrongUser = 'Pogreno korisniko ime/lozinka. Pristup odbijen.';

$strXML = 'XML';

$strYes = 'Da';

$strZeroRemovesTheLimit = 'Napomena: Postavljanje ovih opcija na 0 (nulu) uklanja ogranienja.';
$strZip = '"zipovano"';

// To translate:
$strAccessDeniedCreateConfig = 'Probably reason of this is that you did not create configuration file. You might want to use %1$ssetup script%2$s to create one.';  //to translate
$strAllowInterrupt = 'Allow interrupt of import in case script detects it is close to time limit. This might be good way to import large files, however it can break transactions.';  //to translate

$strBookmarkCreated = 'Bookmark %s created';  //to translate
$strBookmarkReplace = 'Replace existing bookmark of same name';  //to translate
$strBrowseDistinctValues = 'Browse distinct values';  //to translate

$strCanNotLoadImportPlugins = 'Could not load import plugins, please check your installation!';  //to translate
$strCompressionWillBeDetected = 'Imported file compression will be automatically detected from: %s';  //to translate
$strConfigDefaultFileError = 'Could not load default configuration from: "%1$s"';  //to translate
$strCSV = 'CSV';  //to translate
$strCSVImportOptions = 'CSV options';  //to translate

$strDeleteNoUsersSelected = 'No users selected for deleting!';  //to translate

$strErrorInZipFile = 'Error in ZIP archive:';  //to translate
$strEsperanto = 'Esperanto';  //to translate

$strFileNameTemplateDescriptionDatabase = 'database name';  //to translate
$strFileNameTemplateDescriptionServer = 'server name';  //to translate
$strFileNameTemplateDescriptionTable = 'table name';  //to translate
$strFileNameTemplateDescription = 'This value is interpreted using %1$sstrftime%2$s, so you can use time formatting strings. Additionally the following transformations will happen: %3$s. Other text will be kept as is.';  //to translate
$strFileToImport = 'File to import';  //to translate
$strFlushQueryCache = 'Flush query cache';  //to translate
$strFlushTables = 'Flush (close) all tables';  //to translate

$strHandler = 'Handler';  //to translate

$strIgnoreDuplicates = 'Ignore duplicate rows';  //to translate
$strImportFormat = 'Format of imported file';  //to translate
$strImport = 'Import';  //to translate
$strImportSuccessfullyFinished = 'Import has been successfully finished, %d queries executed.';  //to translate
$strInvalidAuthMethod = 'Invalid authentication method set in configuration:';  //to translate
$strInvalidColumn = 'Invalid column (%s) specified!';  //to translate
$strInvalidCSVFieldCount = 'Invalid field count in CSV input on line %d.';  //to translate
$strInvalidCSVFormat = 'Invalid format of CSV input on line %d.';  //to translate
$strInvalidCSVParameter = 'Invalid parameter for CSV import: %s';  //to translate
$strInvalidLDIImport = 'This plugin does not support compressed imports!';  //to translate
$strInvalidServerHostname = 'Invalid hostname for server %1$s. Please review your configuration.';  //to translate
$strInvalidServerIndex = 'Invalid server index: "%s"';  //to translate

$strJoins = 'Joins';  //to translate

$strKeyCache = 'Key cache';  //to translate

$strLanguageFileNotFound = 'Language file "%1$s" not found.';  //to translate
$strLanguageUnknown = 'Unknown language: %1$s.';  //to translate
$strLDI = 'CSV using LOAD DATA';  //to translate
$strLDIImportOptions = 'Options for CSV import using LOAD DATA';  //to translate
$strLDILocal = 'Use LOCAL keyword';  //to translate

$strMaxConnects = 'max. concurrent connections';  //to translate
$strMaximalQueryLength = 'Maximal length of created query';  //to translate
$strMysqlClientVersion = 'MySQL client version';  //to translate

$strNoFilesFoundInZip = 'No files found inside ZIP archive!';  //to translate
$strNumberOfFields = 'Number of fields';  //to translate

$strOpenNewWindow = 'Open new phpMyAdmin window';  //to translate

$strPartialImport = 'Partial import';  //to translate
$strPDFOptions = 'PDF options';  //to translate
$strPDF = 'PDF';  //to translate
$strPDFReportTitle = 'Report title';  //to translate
$strPrivDescMaxUserConnections = 'Limits the number of simultaneous connections the user may have.';  //to translate
$strProtocolVersion = 'Protocol version';  //to translate

$strQueryCache = 'Query cache';  //to translate

$strReloadPrivileges = 'Reload privileges';  //to translate
$strReplication = 'Replication';  //to translate
$strRunSQLQueryOnServer = 'Run SQL query/queries on server %s';  //to translate

$strServerStatusDelayedInserts = 'Delayed inserts';  //to translate
$strShowingBookmark = 'Showing bookmark';  //to translate
$strShowOpenTables = 'Show open tables';  //to translate
$strShowSlaveHosts = 'Show slave hosts';  //to translate
$strShowSlaveStatus = 'Show slave status';  //to translate
$strShowStatusBinlog_cache_disk_useDescr = 'The number of transactions that used the temporary binary log cache but that exceeded the value of binlog_cache_size and used a temporary file to store statements from the transaction.';  //to translate
$strShowStatusBinlog_cache_useDescr = 'The number of transactions that used the temporary binary log cache.';  //to translate
$strShowStatusCreated_tmp_disk_tablesDescr = 'The number of temporary tables on disk created automatically by the server while executing statements. If Created_tmp_disk_tables is big, you may want to increase the tmp_table_size  value to cause temporary tables to be memory-based instead of disk-based.';  //to translate
$strShowStatusCreated_tmp_filesDescr = 'How many temporary files mysqld has created.';  //to translate
$strShowStatusCreated_tmp_tablesDescr = 'The number of in-memory temporary tables created automatically by the server while executing statements.';  //to translate
$strShowStatusDelayed_errorsDescr = 'The number of rows written with INSERT DELAYED for which some error occurred (probably duplicate key).';  //to translate
$strShowStatusDelayed_insert_threadsDescr = 'The number of INSERT DELAYED handler threads in use. Every different table on which one uses INSERT DELAYED gets its own thread.';  //to translate
$strShowStatusDelayed_writesDescr = 'The number of INSERT DELAYED rows written.';  //to translate
$strShowStatusFlush_commandsDescr  = 'The number of executed FLUSH statements.';  //to translate
$strShowStatusHandler_commitDescr = 'The number of internal COMMIT statements.';  //to translate
$strShowStatusHandler_deleteDescr = 'The number of times a row was deleted from a table.';  //to translate
$strShowStatusHandler_discoverDescr = 'The MySQL server can ask the NDB Cluster storage engine if it knows about a table with a given name. This is called discovery. Handler_discover indicates the number of time tables have been discovered.';  //to translate
$strShowStatusHandler_read_firstDescr = 'The number of times the first entry was read from an index. If this is high, it suggests that the server is doing a lot of full index scans; for example, SELECT col1 FROM foo, assuming that col1 is indexed.';  //to translate
$strShowStatusHandler_read_keyDescr = 'The number of requests to read a row based on a key. If this is high, it is a good indication that your queries and tables are properly indexed.';  //to translate
$strShowStatusHandler_read_nextDescr = 'The number of requests to read the next row in key order. This is incremented if you are querying an index column with a range constraint or if you are doing an index scan.';  //to translate
$strShowStatusHandler_read_prevDescr = 'The number of requests to read the previous row in key order. This read method is mainly used to optimize ORDER BY ... DESC.';  //to translate
$strShowStatusHandler_read_rndDescr = 'The number of requests to read a row based on a fixed position. This is high if you are doing a lot of queries that require sorting of the result. You probably have a lot of queries that require MySQL to scan whole tables or you have joins that don\'t use keys properly.';  //to translate
$strShowStatusHandler_read_rnd_nextDescr = 'The number of requests to read the next row in the data file. This is high if you are doing a lot of table scans. Generally this suggests that your tables are not properly indexed or that your queries are not written to take advantage of the indexes you have.';  //to translate
$strShowStatusHandler_rollbackDescr = 'The number of internal ROLLBACK statements.';  //to translate
$strShowStatusHandler_updateDescr = 'The number of requests to update a row in a table.';  //to translate
$strShowStatusHandler_writeDescr = 'The number of requests to insert a row in a table.';  //to translate
$strShowStatusInnodb_buffer_pool_pages_dataDescr = 'The number of pages containing data (dirty or clean).';  //to translate
$strShowStatusInnodb_buffer_pool_pages_dirtyDescr = 'The number of pages currently dirty.';  //to translate
$strShowStatusInnodb_buffer_pool_pages_flushedDescr = 'The number of buffer pool pages that have been requested to be flushed.';  //to translate
$strShowStatusInnodb_buffer_pool_pages_freeDescr = 'The number of free pages.';  //to translate
$strShowStatusInnodb_buffer_pool_pages_latchedDescr = 'The number of latched pages in InnoDB buffer pool. These are pages currently being read or written or that can\'t be flushed or removed for some other reason.';  //to translate
$strShowStatusInnodb_buffer_pool_pages_miscDescr = 'The number of pages busy because they have been allocated for administrative overhead such as row locks or the adaptive hash index. This value can also be calculated as Innodb_buffer_pool_pages_total - Innodb_buffer_pool_pages_free - Innodb_buffer_pool_pages_data.';  //to translate
$strShowStatusInnodb_buffer_pool_pages_totalDescr = 'Total size of buffer pool, in pages.';  //to translate
$strShowStatusInnodb_buffer_pool_read_ahead_rndDescr = 'The number of "random" read-aheads InnoDB initiated. This happens when a query is to scan a large portion of a table but in random order.';  //to translate
$strShowStatusInnodb_buffer_pool_read_ahead_seqDescr = 'The number of sequential read-aheads InnoDB initiated. This happens when InnoDB does a sequential full table scan.';  //to translate
$strShowStatusInnodb_buffer_pool_read_requestsDescr = 'The number of logical read requests InnoDB has done.';  //to translate
$strShowStatusInnodb_buffer_pool_readsDescr = 'The number of logical reads that InnoDB could not satisfy from buffer pool and had to do a single-page read.';  //to translate
$strShowStatusInnodb_buffer_pool_wait_freeDescr = 'Normally, writes to the InnoDB buffer pool happen in the background. However, if it\'s necessary to read or create a page and no clean pages are available, it\'s necessary to wait for pages to be flushed first. This counter counts instances of these waits. If the buffer pool size was set properly, this value should be small.';  //to translate
$strShowStatusInnodb_buffer_pool_write_requestsDescr = 'The number writes done to the InnoDB buffer pool.';  //to translate
$strShowStatusInnodb_data_fsyncsDescr = 'The number of fsync() operations so far.';  //to translate
$strShowStatusInnodb_data_pending_fsyncsDescr = 'The current number of pending fsync() operations.';  //to translate
$strShowStatusInnodb_data_pending_readsDescr = 'The current number of pending reads.';  //to translate
$strShowStatusInnodb_data_pending_writesDescr = 'The current number of pending writes.';  //to translate
$strShowStatusInnodb_data_readDescr = 'The amount of data read so far, in bytes.';  //to translate
$strShowStatusInnodb_data_readsDescr = 'The total number of data reads.';  //to translate
$strShowStatusInnodb_data_writesDescr = 'The total number of data writes.';  //to translate
$strShowStatusInnodb_data_writtenDescr = 'The amount of data written so far, in bytes.';  //to translate
$strShowStatusInnodb_dblwr_pages_writtenDescr = 'The number of doublewrite writes that have been performed and the number of pages that have been written for this purpose.';  //to translate
$strShowStatusInnodb_dblwr_writesDescr = 'The number of doublewrite writes that have been performed and the number of pages that have been written for this purpose.';  //to translate
$strShowStatusInnodb_log_waitsDescr = 'The number of waits we had because log buffer was too small and we had to wait for it to be flushed before continuing.';  //to translate
$strShowStatusInnodb_log_write_requestsDescr = 'The number of log write requests.';  //to translate
$strShowStatusInnodb_log_writesDescr = 'The number of physical writes to the log file.';  //to translate
$strShowStatusInnodb_os_log_fsyncsDescr = 'The number of fsyncs writes done to the log file.';  //to translate
$strShowStatusInnodb_os_log_pending_fsyncsDescr = 'The number of pending log file fsyncs.';  //to translate
$strShowStatusInnodb_os_log_pending_writesDescr = 'Pending log file writes.';  //to translate
$strShowStatusInnodb_os_log_writtenDescr = 'The number of bytes written to the log file.';  //to translate
$strShowStatusInnodb_pages_createdDescr = 'The number of pages created.';  //to translate
$strShowStatusInnodb_page_sizeDescr = 'The compiled-in InnoDB page size (default 16KB). Many values are counted in pages; the page size allows them to be easily converted to bytes.';  //to translate
$strShowStatusInnodb_pages_readDescr = 'The number of pages read.';  //to translate
$strShowStatusInnodb_pages_writtenDescr = 'The number of pages written.';  //to translate
$strShowStatusInnodb_row_lock_current_waitsDescr = 'The number of row locks currently being waited for.';  //to translate
$strShowStatusInnodb_row_lock_time_avgDescr = 'The average time to acquire a row lock, in milliseconds.';  //to translate
$strShowStatusInnodb_row_lock_timeDescr = 'The total time spent in acquiring row locks, in milliseconds.';  //to translate
$strShowStatusInnodb_row_lock_time_maxDescr = 'The maximum time to acquire a row lock, in milliseconds.';  //to translate
$strShowStatusInnodb_row_lock_waitsDescr = 'The number of times a row lock had to be waited for.';  //to translate
$strShowStatusInnodb_rows_deletedDescr = 'The number of rows deleted from InnoDB tables.';  //to translate
$strShowStatusInnodb_rows_insertedDescr = 'The number of rows inserted in InnoDB tables.';  //to translate
$strShowStatusInnodb_rows_readDescr = 'The number of rows read from InnoDB tables.';  //to translate
$strShowStatusInnodb_rows_updatedDescr = 'The number of rows updated in InnoDB tables.';  //to translate
$strShowStatusKey_blocks_not_flushedDescr = 'The number of key blocks in the key cache that have changed but haven\'t yet been flushed to disk. It used to be known as Not_flushed_key_blocks.';  //to translate
$strShowStatusKey_blocks_unusedDescr = 'The number of unused blocks in the key cache. You can use this value to determine how much of the key cache is in use.';  //to translate
$strShowStatusKey_blocks_usedDescr = 'The number of used blocks in the key cache. This value is a high-water mark that indicates the maximum number of blocks that have ever been in use at one time.';  //to translate
$strShowStatusKey_read_requestsDescr = 'The number of requests to read a key block from the cache.';  //to translate
$strShowStatusKey_readsDescr = 'The number of physical reads of a key block from disk. If Key_reads is big, then your key_buffer_size value is probably too small. The cache miss rate can be calculated as Key_reads/Key_read_requests.';  //to translate
$strShowStatusKey_write_requestsDescr = 'The number of requests to write a key block to the cache.';  //to translate
$strShowStatusKey_writesDescr = 'The number of physical writes of a key block to disk.';  //to translate
$strShowStatusLast_query_costDescr = 'The total cost of the last compiled query as computed by the query optimizer. Useful for comparing the cost of different query plans for the same query. The default value of 0 means that no query has been compiled yet.';  //to translate
$strShowStatusNot_flushed_delayed_rowsDescr = 'The number of rows waiting to be written in INSERT DELAY queues.';  //to translate
$strShowStatusOpened_tablesDescr = 'The number of tables that have been opened. If opened tables is big, your table cache value is probably too small.';  //to translate
$strShowStatusOpen_filesDescr = 'The number of files that are open.';  //to translate
$strShowStatusOpen_streamsDescr = 'The number of streams that are open (used mainly for logging).';  //to translate
$strShowStatusOpen_tablesDescr = 'The number of tables that are open.';  //to translate
$strShowStatusQcache_free_blocksDescr = 'The number of free memory blocks in query cache.';  //to translate
$strShowStatusQcache_free_memoryDescr = 'The amount of free memory for query cache.';  //to translate
$strShowStatusQcache_hitsDescr = 'The number of cache hits.';  //to translate
$strShowStatusQcache_insertsDescr = 'The number of queries added to the cache.';  //to translate
$strShowStatusQcache_lowmem_prunesDescr = 'The number of queries that have been removed from the cache to free up memory for caching new queries. This information can help you tune the query cache size. The query cache uses a least recently used (LRU) strategy to decide which queries to remove from the cache.';  //to translate
$strShowStatusQcache_not_cachedDescr = 'The number of non-cached queries (not cachable, or not cached due to the query_cache_type setting).';  //to translate
$strShowStatusQcache_queries_in_cacheDescr = 'The number of queries registered in the cache.';  //to translate
$strShowStatusQcache_total_blocksDescr = 'The total number of blocks in the query cache.';  //to translate
$strShowStatusReset = 'Reset';  //to translate
$strShowStatusRpl_statusDescr = 'The status of failsafe replication (not yet implemented).';  //to translate
$strShowStatusSelect_full_joinDescr = 'The number of joins that do not use indexes. If this value is not 0, you should carefully check the indexes of your tables.';  //to translate
$strShowStatusSelect_full_range_joinDescr = 'The number of joins that used a range search on a reference table.';  //to translate
$strShowStatusSelect_range_checkDescr = 'The number of joins without keys that check for key usage after each row. (If this is not 0, you should carefully check the indexes of your tables.)';  //to translate
$strShowStatusSelect_rangeDescr = 'The number of joins that used ranges on the first table. (It\'s normally not critical even if this is big.)';  //to translate
$strShowStatusSelect_scanDescr = 'The number of joins that did a full scan of the first table.';  //to translate
$strShowStatusSlave_open_temp_tablesDescr = 'The number of temporary tables currently open by the slave SQL thread.';  //to translate
$strShowStatusSlave_retried_transactionsDescr = 'Total (since startup) number of times the replication slave SQL thread has retried transactions.';  //to translate
$strShowStatusSlave_runningDescr = 'This is ON if this server is a slave that is connected to a master.';  //to translate
$strShowStatusSlow_launch_threadsDescr = 'The number of threads that have taken more than slow_launch_time seconds to create.';  //to translate
$strShowStatusSlow_queriesDescr = 'The number of queries that have taken more than long_query_time seconds.';  //to translate
$strShowStatusSort_merge_passesDescr = 'The number of merge passes the sort algorithm has had to do. If this value is large, you should consider increasing the value of the sort_buffer_size system variable.';  //to translate
$strShowStatusSort_rangeDescr = 'The number of sorts that were done with ranges.';  //to translate
$strShowStatusSort_rowsDescr = 'The number of sorted rows.';  //to translate
$strShowStatusSort_scanDescr = 'The number of sorts that were done by scanning the table.';  //to translate
$strShowStatusTable_locks_immediateDescr = 'The number of times that a table lock was acquired immediately.';  //to translate
$strShowStatusTable_locks_waitedDescr = 'The number of times that a table lock could not be acquired immediately and a wait was needed. If this is high, and you have performance problems, you should first optimize your queries, and then either split your table or tables or use replication.';  //to translate
$strShowStatusThreads_cachedDescr = 'The number of threads in the thread cache. The cache hit rate can be calculated as Threads_created/Connections. If this value is red you should raise your thread_cache_size.';  //to translate
$strShowStatusThreads_connectedDescr = 'The number of currently open connections.';  //to translate
$strShowStatusThreads_createdDescr = 'The number of threads created to handle connections. If Threads_created is big, you may want to increase the thread_cache_size value. (Normally this doesn\'t give a notable performance improvement if you have a good thread implementation.)';  //to translate
$strShowStatusThreads_runningDescr = 'The number of threads that are not sleeping.';  //to translate
$strSkipQueries = 'Number of records(queries) to skip from start';  //to translate
$strSorting = 'Sorting';  //to translate
$strSQLCompatibility = 'SQL compatibility mode';  //to translate
$strSQLImportOptions = 'SQL options';  //to translate
$strStatisticsOverrun = 'On a busy server, the byte counters may overrun, so those statistics as reported by the MySQL server may be incorrect.';  //to translate

$strTableAlreadyExists = 'Table %s already exists!';  //to translate
$strTempData = 'Temporary data';  //to translate
$strThemeDefaultNotFound = 'Default theme %s not found!';  //to translate
$strThemeNoPreviewAvailable = 'No preview available.';  //to translate
$strThemeNotFound = 'Theme %s not found!';  //to translate
$strThemeNoValidImgPath = 'No valid image path for theme %s found!';  //to translate
$strThemePathNotFound = 'Theme path not found for theme %s!';  //to translate
$strThreads = 'Threads';  //to translate
$strTimeoutInfo = 'Previous import timed out, after resubmitting will continue from position %d.';  //to translate
$strTimeoutNothingParsed = 'However on last run no data has been parsed, this usually means phpMyAdmin won\'t be able to finish this import unless you increase php time limits.';  //to translate
$strTimeoutPassed = 'Script timeout passed, if you want to finish import, please resubmit same file and import will resume.';  //to translate
$strTransactionCoordinator = 'Transaction coordinator';  //to translate
$strTransformation_text_plain__sql = 'Formats text as SQL query with syntax highlighting.';  //to translate

$strUnsupportedCompressionDetected = 'You attempted to load file with unsupported compression (%s). Either support for it is not implemented or disabled by your configuration.';  //to translate
$strUploadLimit = 'You probably tried to upload too large file. Please refer to %sdocumentation%s for ways to workaround this limit.';  //to translate
$strUsedPhpExtensions = 'Used PHP extensions';  //to translate

$strViewMaxExactCount = 'This view has more than %s rows. Please refer to %sdocumentation%s.';  //to translate

$strQueryResultsOperations = 'Query results operations';  //to translate
$strAddClause = 'Add %s';  //to translate
$strUploadsNotAllowed = 'File uploads are not allowed on this server.';  //to translate
$strOpenDocumentSpreadsheet = 'Open Document Spreadsheet';  //to translate
$strOpenDocumentSpreadsheetOptions = 'Open Document Spreadsheet options';  //to translate
$strExportMustBeFile = 'Selected export type has to be saved in file!';  //to translate
$strXMLOptions = 'XML options';  //to translate
$strStrucNativeExcelOptions = 'Native Excel export options';  //to translate
$strCreateUserDatabase = 'Database for user';  //to translate
$strCreateUserDatabaseNone = 'None';  //to translate
$strCreateUserDatabaseName = 'Create database with same name and grant all privileges';  //to translate
$strCreateUserDatabaseWildcard = 'Grant all privileges on wildcard name (username\_%)';  //to translate
$strOpenDocumentText = 'Open Document Text';  //to translate
$strOpenDocumentTextOptions = 'Open Document Text options';  //to translate
$strNoDataReceived = 'No data was received to import. Either no file name was submitted, or the file size exceeded the maximum size permitted by your PHP configuration. See FAQ 1.16.';  //to translate
$strCanNotLoadExportPlugins = 'Could not load export plugins, please check your installation!';  //to translate
$strErrorRenamingTable = 'Error renaming table %1$s to %2$s';  //to translate
$strInvalidTableName = 'Invalid table name';  //to translate
$strInvalidDatabase = 'Invalid database';  //to translate
$strServers = 'Servers';  //to translate
$strDelimiter = 'Delimiter';  //to translate
$strFunctions = 'Functions';  //to translate
$strProcedures = 'Procedures';  //to translate
$strPDFReportExplanation = '(Generates a report containing the data of a single table)';  //to translate
$strFontSize = 'Font size';  //to translate
$strLanguage = 'Language';  //to translate
$strPmaWiki = 'phpMyAdmin wiki';  //to translate
$strTransformation_text_plain__dateformat = 'Displays a TIME, TIMESTAMP, DATETIME or numeric unix timestamp field as formatted date. The first option is the offset (in hours) which will be added to the timestamp (Default: 0). Use second option to specify a different date/time format string. Third option determines whether you want to see local date or UTC one (use "local" or "utc" strings) for that. According to that, date format has different value - for "local" see the documentation for PHP\'s strftime() function and for "utc" it is done using gmdate() function.';  //to translate
$strDocSQL = 'DocSQL';  //to translate
$strDocSQLOptions = 'DocSQL options';  //to translate
$strTableName = 'Table name';  //to translate
$strTableIsEmpty = 'Table seems to be empty!';  //to translate
$strDbIsEmpty = 'Database seems to be empty!';  //to translate
$strShowingPhp = 'Showing as PHP code';  //to translate
$strShowingSQL = 'Showing SQL query';  //to translate
$strDesigner = 'Designer';  //to translate
$strNumberOfTables = 'Number of tables';  //to translate
$strCreateTable  = 'Create table';  //to translate
$strCreateRelation = 'Create relation';  //to translate
$strSavePosition = 'Save position';  //to translate
$strSelectForeignKey = 'Select Foreign Key';  //to translate
$strHide         = 'Hide';  //to translate
$strShowHideLeftMenu = 'Show/Hide left menu';  //to translate
$strReload = 'Reload';  //to translate
$strSmallBigAll = 'Small/Big All';  //to translate
$strImportExportCoords = 'Import/Export coordinates for PDF schema';  //to translate
$strMoveMenu = 'Move Menu';  //to translate
$strAngularLinks = 'Angular links';  //to translate
$strDirectLinks = 'Direct links';  //to translate
$strHideShowAll = 'Hide/Show all';  //to translate
$strHideShowNoRelation = 'Hide/Show Tables with no relation';  //to translate
$strInternalRelationAdded = 'Internal relation added';  //to translate
$strInnoDBRelationAdded = 'InnoDB relation added';  //to translate
$strRelationDeleted = 'Relation deleted';  //to translate
$strToSelectRelation = 'To select relation, click :';  //to translate
$strExportImportToScale = 'Export/Import to scale';  //to translate
$strRecommended = 'recommended';  //to translate
$strToFromPage = 'to/from page';  //to translate
$strSelectReferencedKey = 'Select referenced key';  //to translate
$strPleaseSelectPrimaryOrUniqueKey = 'Please select the primary key or a unique key';  //to translate
$strForeignKeyError = 'Error creating foreign key (check data types)';  //to translate
$strHelp = 'Help';  //to translate
$strCancel = 'Cancel';  //to translate
$strDeleteRelation = 'Delete relation';  //to translate
$strKnownExternalBug = 'The %s functionality is affected by a known bug, see %s';  //to translate
$strStructureForView = 'Structure for view';  //to translate
$strStandInStructureForView = 'Stand-in structure for view';  //to translate
$strToggleSmallBig = 'Toggle small/big';  //to translate
$strIEUnsupported = 'Internet Explorer does not support this function.';  //to translate
$strErrorRelationAdded = 'Error: Relation not added.';  //to translate
$strErrorRelationExists = 'Error: relation already exists.';  //to translate
$strErrorSaveTable = 'Error saving coordinates for Designer.';  //to translate
$strSnapToGrid = 'Snap to grid';  //to translate
$strDesignerHelpDisplayField = 'The display field is shown in pink. To set/unset a field as the display field, click the "Choose field to display" icon, then click on the appropriate field name.';  //to translate
?>
